@@ -10,7 +10,7 @@ def test_feature_manager():
 @change_working_dir_pytest
 def test_feature_manager_with_prediction_feature():
     feature_config_path = "configs/feature_config.yaml"
-    fm = feature_manager.FeatureManager(feature_config_path)
+    fm = feature_manager.FeatureManager.from_config_path(feature_config_path)
     fm.compute_prediction_features(["pred_lgbm_for_test"])
 
 
